@@ -128,11 +128,14 @@ class ContentManager:
             body = f.read()
         if filename.endswith('.css'):
             content_type = 'text/css'
+        elif filename.endswith('.svg'):
+            content_type = 'image/svg+xml'
         elif filename.endswith('.js') or filename.endswith('.mjs'):
             content_type = 'text/javascript'
         else:
             content_type = self.__magic.from_buffer(body)
 
+        print(f'[{filename}]: Was {content_type}')
         isBase64Encoded = False
         if content_type.startswith('image/'):
             if self.__app.current_request:
@@ -141,11 +144,26 @@ class ContentManager:
                     body = self.convert_by_accepts(body, accepts)
                     content_type = self.__magic.from_buffer(body)
             isBase64Encoded = True
+        print(f'[{filename}]: Is {content_type}')
         h["Content-Type"] = content_type
         r = ResponseWithBinary(body=body, status_code=status_code, headers=h)
         r.isBase64Encoded = isBase64Encoded
         return r
 
+    def xml(self, body:str, status_code:int=200, headers:Optional[dict]=None) -> Response:
+        """
+        Useful for returning xml content that has been rendered already using render_template().
+
+        :param body: String containing rendered template
+        :param status_code: Status code to return content with
+        :param headers: Additional headers to return
+        :returns: Chalice Response object
+        """
+        h = {"Content-Type": "text/xml", "Access-Control-Allow-Origin": "*"}
+        if headers:
+            h = {**h, **headers}
+        return Response(body=body, status_code=status_code, headers=h)
+
     def html(self, body:str, status_code:int=200, headers:Optional[dict]=None) -> Response:
         """
         Useful for returning html content that has been rendered already using render_template().
